@@ -14,7 +14,7 @@ void kzf(double *y, long *n_arg, long *q_arg, double *d, long *k_arg)
 	kz(y, n_arg, q_arg, k_arg);
 	
 	/* calculate d = |Z(t+q) - Z(t-q)| */
-	for (i=0; i<q; i++) d[i] = fabs(y[i+q] - y[0]);
+	for (i=0; i<q; i++) {d[i] = fabs(y[i+q] - y[0]);}
 	for (i=q; i<n-q; i++) {d[i] = fabs(y[i+q] - y[i-q]);}
 	for (i=n-q; i<n; i++) {d[i] = fabs(y[n-1] - y[i]);}
 }    
